@@ -73,17 +73,17 @@ static void C_deriv_func_dop (int *neq, double *t, double *y,
                           double *ydot, double *yout, int *iout)
 {
   int i;
-  SEXP R_fcall, ans;
+  SEXP R_fcall, Time, ans;
 
-                              REAL(Time)[0] = *t;
   for (i = 0; i < *neq; i++)  REAL(Y)[i] = y[i];
 
+  PROTECT(Time = ScalarReal(*t));                  incr_N_Protect();
   PROTECT(R_fcall = lang3(R_deriv_func,Time,Y));   incr_N_Protect();
   PROTECT(ans = eval(R_fcall, R_envir));           incr_N_Protect();
 
   for (i = 0; i < *neq; i++)   ydot[i] = REAL(ans)[i];
 
-  my_unprotect(2);
+  my_unprotect(3);
 }
 
 /* deriv output function - for ordinary output variables */
@@ -92,18 +92,18 @@ static void C_deriv_out_dop (int *nOut, double *t, double *y,
                        double *ydot, double *yout)
 {
   int i;
-  SEXP R_fcall, ans;
+  SEXP R_fcall, Time, ans;
   
-  REAL(Time)[0] = *t;
   for (i = 0; i < n_eq; i++)  
       REAL(Y)[i] = y[i];
      
+  PROTECT(Time = ScalarReal(*t));                   incr_N_Protect();
   PROTECT(R_fcall = lang3(R_deriv_func,Time, Y));   incr_N_Protect();
   PROTECT(ans = eval(R_fcall, R_envir));            incr_N_Protect();
 
   for (i = 0; i < *nOut; i++) yout[i] = REAL(ans)[i + n_eq];
 
-  my_unprotect(2);                                  
+  my_unprotect(3);                                  
 }      
 
 /* save output in R-variables */
